@@ -7,16 +7,30 @@ use crate::{
     ratelimiting::Ratelimiter,
     request::{
         application::{
-            CreateFollowupMessage, CreateGlobalCommand, CreateGuildCommand, DeleteFollowupMessage,
-            DeleteGlobalCommand, DeleteGuildCommand, DeleteOriginalResponse, GetCommandPermissions,
-            GetGlobalCommands, GetGuildCommandPermissions, GetGuildCommands, GetOriginalResponse,
-            InteractionCallback, InteractionError, InteractionErrorType, SetCommandPermissions,
-            SetGlobalCommands, SetGuildCommands, UpdateCommandPermissions, UpdateFollowupMessage,
-            UpdateGlobalCommand, UpdateGuildCommand, UpdateOriginalResponse,
+            command::{
+                create_global_command::CreateGlobalChatInputCommand,
+                create_guild_command::CreateGuildChatInputCommand, CreateGlobalCommand,
+                CreateGuildCommand, DeleteGlobalCommand, DeleteGuildCommand, GetCommandPermissions,
+                GetGlobalCommand, GetGlobalCommands, GetGuildCommand, GetGuildCommandPermissions,
+                GetGuildCommands, SetCommandPermissions, SetGlobalCommands, SetGuildCommands,
+                UpdateCommandPermissions, UpdateGlobalCommand, UpdateGuildCommand,
+            },
+            interaction::{
+                CreateFollowupMessage, DeleteFollowupMessage, DeleteOriginalResponse,
+                GetFollowupMessage, GetOriginalResponse, InteractionCallback,
+                UpdateFollowupMessage, UpdateOriginalResponse,
+            },
+            InteractionError, InteractionErrorType,
         },
         channel::{
             reaction::delete_reaction::TargetUser,
             stage::create_stage_instance::CreateStageInstanceError,
+            thread::{
+                AddThreadMember, CreateThread, CreateThreadFromMessage,
+                GetJoinedPrivateArchivedThreads, GetPrivateArchivedThreads,
+                GetPublicArchivedThreads, GetThreadMembers, JoinThread, LeaveThread,
+                RemoveThreadMember, ThreadValidationError, UpdateThread,
+            },
         },
         guild::{
             create_guild::CreateGuildError, create_guild_channel::CreateGuildChannelError,
@@ -48,7 +62,9 @@ use twilight_model::{
         callback::InteractionResponse,
         command::{permissions::CommandPermissions, Command},
     },
-    channel::message::allowed_mentions::AllowedMentions,
+    channel::{
+        message::allowed_mentions::AllowedMentions, thread::AutoArchiveDuration, ChannelType,
+    },
     guild::Permissions,
     id::{
         ApplicationId, ChannelId, CommandId, EmojiId, GuildId, IntegrationId, InteractionId,
@@ -1517,6 +1533,171 @@ impl Client {
         UpdateTemplate::new(self, guild_id, template_code)
     }
 
+    /// Returns all active threads in the channel.
+    ///
+    /// Includes public and private threads. Threads are ordered by their ID in
+    /// descending order.
+    pub const fn active_threads(&self, guild_id: GuildId) -> GetActiveThreads<'_> {
+        GetActiveThreads::new(self, guild_id)
+    }
+
+    /// Add another member to a thread.
+    ///
+    /// Requires the ability to send messages in the thread, and that the thread
+    /// is not archived.
+    pub const fn add_thread_member(
+        &self,
+        channel_id: ChannelId,
+        user_id: UserId,
+    ) -> AddThreadMember<'_> {
+        AddThreadMember::new(self, channel_id, user_id)
+    }
+
+    /// Start a thread that is not connected to a message.
+    ///
+    /// Values of [`ThreeDays`] and [`Week`] require the guild to be boosted.
+    /// The guild's features will indicate if a guild is able to use these
+    /// settings.
+    ///
+    /// To make a [`GuildPrivateThread`], the guild must also have the
+    /// `PRIVATE_THREADS` feature.
+    ///
+    /// [`GuildPrivateThread`]: twilight_model::channel::ChannelType::GuildPrivateThread
+    /// [`ThreeDays`]: twilight_model::channel::thread::AutoArchiveDuration::ThreeDays
+    /// [`Week`]: twilight_model::channel::thread::AutoArchiveDuration::Week
+    pub fn create_thread<'a>(
+        &'a self,
+        channel_id: ChannelId,
+        name: &'a str,
+        auto_archive_duration: AutoArchiveDuration,
+        kind: ChannelType,
+    ) -> Result<CreateThread<'_>, ThreadValidationError> {
+        CreateThread::new(self, channel_id, name, auto_archive_duration, kind)
+    }
+
+    /// Create a new thread from an existing message.
+    ///
+    /// When called on a [`GuildText`] channel, this creates a
+    /// [`GuildPublicThread`].
+    ///
+    /// When called on a [`GuildNews`] channel, this creates a
+    /// [`GuildNewsThread`].
+    ///
+    /// Values of [`ThreeDays`] and [`Week`] require the guild to be boosted.
+    /// The guild's features will indicate if a guild is able to use these
+    /// settings.
+    ///
+    /// The thread's ID will be the same as its parent message. This ensures
+    /// only one thread can be created per message.
+    ///
+    /// [`GuildNewsThread`]: twilight_model::channel::ChannelType::GuildNewsThread
+    /// [`GuildNews`]: twilight_model::channel::ChannelType::GuildNews
+    /// [`GuildPublicThread`]: twilight_model::channel::ChannelType::GuildPublicThread
+    /// [`GuildText`]: twilight_model::channel::ChannelType::GuildText
+    /// [`ThreeDays`]: twilight_model::channel::thread::AutoArchiveDuration::ThreeDays
+    /// [`Week`]: twilight_model::channel::thread::AutoArchiveDuration::Week
+    pub fn create_thread_from_message<'a>(
+        &'a self,
+        channel_id: ChannelId,
+        message_id: MessageId,
+        name: &'a str,
+        auto_archive_duration: AutoArchiveDuration,
+    ) -> Result<CreateThreadFromMessage<'_>, ThreadValidationError> {
+        CreateThreadFromMessage::new(self, channel_id, message_id, name, auto_archive_duration)
+    }
+
+    /// Add the current user to a thread.
+    pub const fn join_thread(&self, channel_id: ChannelId) -> JoinThread<'_> {
+        JoinThread::new(self, channel_id)
+    }
+
+    /// Returns archived private threads in the channel that the current user
+    /// has joined.
+    ///
+    /// Threads are ordered by their ID in descending order.
+    pub const fn joined_private_archived_threads(
+        &self,
+        channel_id: ChannelId,
+    ) -> GetJoinedPrivateArchivedThreads<'_> {
+        GetJoinedPrivateArchivedThreads::new(self, channel_id)
+    }
+
+    /// Remove the current user from a thread.
+    ///
+    /// Requires that the thread is not archived.
+    pub const fn leave_thread(&self, channel_id: ChannelId) -> LeaveThread<'_> {
+        LeaveThread::new(self, channel_id)
+    }
+
+    /// Returns archived private threads in the channel.
+    ///
+    /// Requires both [`READ_MESSAGE_HISTORY`] and [`MANAGE_THREADS`].
+    ///
+    /// [`MANAGE_THREADS`]: twilight_model::guild::Permissions::MANAGE_THREADS
+    /// [`READ_MESSAGE_HISTORY`]: twilight_model::guild::Permissions::READ_MESSAGE_HISTORY
+    pub const fn private_archived_threads(
+        &self,
+        channel_id: ChannelId,
+    ) -> GetPrivateArchivedThreads<'_> {
+        GetPrivateArchivedThreads::new(self, channel_id)
+    }
+
+    /// Returns archived public threads in the channel.
+    ///
+    /// Requires the [`READ_MESSAGE_HISTORY`] permission.
+    ///
+    /// Threads are ordered by [`archive_timestamp`] in descending order.
+    ///
+    /// When called in a [`GuildText`] channel, returns [`GuildPublicThread`]s.
+    ///
+    /// When called in a [`GuildNews`] channel, returns [`GuildNewsThread`]s.
+    ///
+    /// [`archive_timestamp`]: twilight_model::channel::thread::ThreadMetadata::archive_timestamp
+    /// [`GuildNews`]: twilight_model::channel::ChannelType::GuildNews
+    /// [`GuildNewsThread`]: twilight_model::channel::ChannelType::GuildNewsThread
+    /// [`GuildPublicThread`]: twilight_model::channel::ChannelType::GuildPublicThread
+    /// [`GuildText`]: twilight_model::channel::ChannelType::GuildText
+    /// [`READ_MESSAGE_HISTORY`]: twilight_model::guild::Permissions::READ_MESSAGE_HISTORY
+    pub const fn public_archived_threads(
+        &self,
+        channel_id: ChannelId,
+    ) -> GetPublicArchivedThreads<'_> {
+        GetPublicArchivedThreads::new(self, channel_id)
+    }
+
+    /// Remove another member from a thread.
+    ///
+    /// Requires that the thread is not archived.
+    ///
+    /// Requires the [`MANAGE_THREADS`] permission, unless both the thread is a
+    /// [`GuildPrivateThread`], and the current user is the creator of the
+    /// thread.
+    ///
+    /// [`GuildPrivateThread`]: twilight_model::channel::ChannelType::GuildPrivateThread
+    /// [`MANAGE_THREADS`]: twilight_model::guild::Permissions::MANAGE_THREADS
+    pub const fn remove_thread_member(
+        &self,
+        channel_id: ChannelId,
+        user_id: UserId,
+    ) -> RemoveThreadMember<'_> {
+        RemoveThreadMember::new(self, channel_id, user_id)
+    }
+
+    /// Returns the [`ThreadMember`]s of the thread.
+    ///
+    /// [`ThreadMember`]: twilight_model::channel::thread::ThreadMember
+    pub const fn thread_members(&self, channel_id: ChannelId) -> GetThreadMembers<'_> {
+        GetThreadMembers::new(self, channel_id)
+    }
+
+    /// Update a thread.
+    ///
+    /// All fields are optional. The minimum length of the name is 1 UTF-16
+    /// characters and the maximum is 100 UTF-16 characters.
+    pub const fn update_thread(&self, channel_id: ChannelId) -> UpdateThread<'_> {
+        UpdateThread::new(self, channel_id)
+    }
+
     /// Get a user's information by id.
     pub const fn user(&self, user_id: UserId) -> GetUser<'_> {
         GetUser::new(self, user_id)
@@ -1746,6 +1927,30 @@ impl Client {
         ))
     }
 
+    /// Get a followup message of an interaction.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    pub fn followup_message<'a>(
+        &'a self,
+        interaction_token: &'a str,
+        message_id: MessageId,
+    ) -> Result<GetFollowupMessage<'a>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        Ok(GetFollowupMessage::new(
+            self,
+            application_id,
+            interaction_token,
+            message_id,
+        ))
+    }
+
     /// Delete the original message, by its token.
     ///
     /// # Errors
@@ -1838,10 +2043,9 @@ impl Client {
         ))
     }
 
-    /// Create a new command in a guild.
+    /// Create a new chat input command in a guild.
     ///
-    /// The name must be between 3 and 32 characters in length, and the
-    /// description must be between 1 and 100 characters in length. Creating a
+    /// The name must be between 1 and 32 characters in length. Creating a
     /// guild command with the same name as an already-existing guild command in
     /// the same guild will overwrite the old command. See [the discord docs]
     /// for more information.
@@ -1853,24 +2057,77 @@ impl Client {
     /// [`Client::set_application_id`].
     ///
     /// Returns an [`InteractionErrorType::CommandNameValidationFailed`]
-    /// error type if the command name is not between 3 and 32 characters.
+    /// error type if the command name is not between 1 and 32 characters.
     ///
-    /// Returns an [`InteractionErrorType::CommandDescriptionValidationFailed`]
-    /// error type if the command description is not between 1 and
-    /// 100 characters.
-    ///
-    /// [the discord docs]: https://discord.com/developers/docs/interactions/slash-commands#create-guild-application-command
+    /// [the discord docs]: https://discord.com/developers/docs/interactions/application-commands#create-guild-application-command
+    #[deprecated(
+        note = "use `new_create_guild_command`, which does not require a description",
+        since = "0.6.4"
+    )]
     pub fn create_guild_command<'a>(
         &'a self,
         guild_id: GuildId,
         name: &'a str,
         description: &'a str,
+    ) -> Result<CreateGuildChatInputCommand<'a>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        CreateGuildCommand::new(self, application_id, guild_id, name)?.chat_input(description)
+    }
+
+    /// Create a new command in a guild.
+    ///
+    /// The name must be between 1 and 32 characters in length. Creating a
+    /// guild command with the same name as an already-existing guild command in
+    /// the same guild will overwrite the old command. See [the discord docs]
+    /// for more information.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    ///
+    /// Returns an [`InteractionErrorType::CommandNameValidationFailed`]
+    /// error type if the command name is not between 1 and 32 characters.
+    ///
+    /// [the discord docs]: https://discord.com/developers/docs/interactions/application-commands#create-guild-application-command
+    pub fn new_create_guild_command<'a>(
+        &'a self,
+        guild_id: GuildId,
+        name: &'a str,
     ) -> Result<CreateGuildCommand<'a>, InteractionError> {
         let application_id = self.application_id().ok_or(InteractionError {
             kind: InteractionErrorType::ApplicationIdNotPresent,
         })?;
 
-        CreateGuildCommand::new(self, application_id, guild_id, name, description)
+        CreateGuildCommand::new(self, application_id, guild_id, name)
+    }
+
+    /// Fetch a guild command for your application.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    pub fn get_guild_command(
+        &self,
+        guild_id: GuildId,
+        command_id: CommandId,
+    ) -> Result<GetGuildCommand<'_>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        Ok(GetGuildCommand::new(
+            self,
+            application_id,
+            guild_id,
+            command_id,
+        ))
     }
 
     /// Fetch all commands for a guild, by ID.
@@ -1902,7 +2159,7 @@ impl Client {
     /// error type if an application ID has not been configured via
     /// [`Client::set_application_id`].
     ///
-    /// [the discord docs]: https://discord.com/developers/docs/interactions/slash-commands#edit-guild-application-command
+    /// [the discord docs]: https://discord.com/developers/docs/interactions/application-commands#edit-guild-application-command
     pub fn update_guild_command(
         &self,
         guild_id: GuildId,
@@ -1971,10 +2228,46 @@ impl Client {
         ))
     }
 
+    /// Create a new chat input global command.
+    ///
+    /// The name must be between 1 and 32 characters in length. The description
+    /// must be between 1 and 100 characters in length. Creating a command with
+    /// the same name as an already-existing global command will overwrite the
+    /// old command. See [the discord docs] for more information.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    ///
+    /// Returns an [`InteractionErrorType::CommandNameValidationFailed`]
+    /// error type if the command name is not between 1 and 32 characters.
+    ///
+    /// Returns an [`InteractionErrorType::CommandDescriptionValidationFailed`]
+    /// error type if the command description is not between 1 and 100
+    /// characters.
+    ///
+    /// [the discord docs]: https://discord.com/developers/docs/interactions/application-commands#create-global-application-command
+    #[deprecated(
+        note = "use `new_create_global_command`, which does not require a description",
+        since = "0.6.4"
+    )]
+    pub fn create_global_command<'a>(
+        &'a self,
+        name: &'a str,
+        description: &'a str,
+    ) -> Result<CreateGlobalChatInputCommand<'a>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        CreateGlobalCommand::new(self, application_id, name)?.chat_input(description)
+    }
+
     /// Create a new global command.
     ///
-    /// The name must be between 3 and 32 characters in length, and the
-    /// description must be between 1 and 100 characters in length. Creating a
+    /// The name must be between 1 and 32 characters in length. Creating a
     /// command with the same name as an already-existing global command will
     /// overwrite the old command. See [the discord docs] for more information.
     ///
@@ -1985,23 +2278,36 @@ impl Client {
     /// [`Client::set_application_id`].
     ///
     /// Returns an [`InteractionErrorType::CommandNameValidationFailed`]
-    /// error type if the command name is not between 3 and 32 characters.
+    /// error type if the command name is not between 1 and 32 characters.
     ///
-    /// Returns an [`InteractionErrorType::CommandDescriptionValidationFailed`]
-    /// error type if the command description is not between 1 and
-    /// 100 characters.
-    ///
-    /// [the discord docs]: https://discord.com/developers/docs/interactions/slash-commands#create-global-application-command
-    pub fn create_global_command<'a>(
+    /// [the discord docs]: https://discord.com/developers/docs/interactions/application-commands#create-global-application-command
+    pub fn new_create_global_command<'a>(
         &'a self,
         name: &'a str,
-        description: &'a str,
     ) -> Result<CreateGlobalCommand<'a>, InteractionError> {
         let application_id = self.application_id().ok_or(InteractionError {
             kind: InteractionErrorType::ApplicationIdNotPresent,
         })?;
 
-        CreateGlobalCommand::new(self, application_id, name, description)
+        CreateGlobalCommand::new(self, application_id, name)
+    }
+
+    /// Fetch a global command for your application.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    pub fn get_global_command(
+        &self,
+        command_id: CommandId,
+    ) -> Result<GetGlobalCommand<'_>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        Ok(GetGlobalCommand::new(self, application_id, command_id))
     }
 
     /// Fetch all global commands for your application.
@@ -2030,7 +2336,7 @@ impl Client {
     /// error type if an application ID has not been configured via
     /// [`Client::set_application_id`].
     ///
-    /// [the discord docs]: https://discord.com/developers/docs/interactions/slash-commands#edit-global-application-command
+    /// [the discord docs]: https://discord.com/developers/docs/interactions/application-commands#edit-global-application-command
     pub fn update_global_command(
         &self,
         command_id: CommandId,
