@@ -14,6 +14,7 @@ mod private {
         channel::{
             invite::{CreateInvite, DeleteInvite},
             message::{DeleteMessage, DeleteMessages},
+            thread::UpdateThread,
             webhook::{
                 CreateWebhook, DeleteWebhook, DeleteWebhookMessage, UpdateWebhook,
                 UpdateWebhookMessage,
@@ -63,6 +64,7 @@ mod private {
     impl<'a> Sealed for DeleteRole<'a> {}
     impl<'a> Sealed for UpdateRole<'a> {}
     impl<'a> Sealed for UpdateGuild<'a> {}
+    impl<'a> Sealed for UpdateThread<'a> {}
     impl Sealed for UpdateWebhookMessage<'_> {}
 }
 
