@@ -13,6 +13,7 @@ pub mod update_guild_channel_positions;
 pub mod user;
 
 mod delete_guild;
+mod get_active_threads;
 mod get_guild;
 mod get_guild_channels;
 mod get_guild_invites;
@@ -28,8 +29,9 @@ mod update_guild_widget;
 
 pub use self::{
     create_guild::CreateGuild, create_guild_channel::CreateGuildChannel,
-    create_guild_prune::CreateGuildPrune, delete_guild::DeleteGuild, get_audit_log::GetAuditLog,
-    get_guild::GetGuild, get_guild_channels::GetGuildChannels, get_guild_invites::GetGuildInvites,
+    create_guild_prune::CreateGuildPrune, delete_guild::DeleteGuild,
+    get_active_threads::GetActiveThreads, get_audit_log::GetAuditLog, get_guild::GetGuild,
+    get_guild_channels::GetGuildChannels, get_guild_invites::GetGuildInvites,
     get_guild_preview::GetGuildPreview, get_guild_prune_count::GetGuildPruneCount,
     get_guild_vanity_url::GetGuildVanityUrl, get_guild_voice_regions::GetGuildVoiceRegions,
     get_guild_webhooks::GetGuildWebhooks, get_guild_welcome_screen::GetGuildWelcomeScreen,
