@@ -16,6 +16,13 @@ pub enum Route<'a> {
         /// The ID of the user.
         user_id: u64,
     },
+    /// Route information to add a member to a thread.
+    AddThreadMember {
+        /// ID of the thread.
+        channel_id: u64,
+        /// ID of the member.
+        user_id: u64,
+    },
     /// Route information to create a ban on a user in a guild.
     CreateBan {
         /// The number of days' worth of the user's messages to delete in the
@@ -89,6 +96,18 @@ pub enum Route<'a> {
     },
     /// Route information to create a private channel.
     CreatePrivateChannel,
+    /// Route information to create a thread in a channel.
+    CreateThread {
+        /// ID of the channel.
+        channel_id: u64,
+    },
+    /// Route information to create a thread from a message.
+    CreateThreadFromMessage {
+        /// ID of the channel.
+        channel_id: u64,
+        /// ID of the message.
+        message_id: u64,
+    },
     /// Route information to create a reaction on a message.
     CreateReaction {
         /// The ID of the channel.
@@ -289,6 +308,11 @@ pub enum Route<'a> {
         /// The ID of the channel to follow.
         channel_id: u64,
     },
+    /// Route information to get active threads in a channel.
+    GetActiveThreads {
+        /// ID of the guild.
+        guild_id: u64,
+    },
     /// Route information to get a paginated list of audit logs in a guild.
     GetAuditLogs {
         /// The type of action to get audit logs for.
@@ -359,11 +383,27 @@ pub enum Route<'a> {
         /// The ID of the guild.
         guild_id: u64,
     },
+    /// Route to get a followup message for an interaction.
+    GetFollowupMessage {
+        /// ID of the application.
+        application_id: u64,
+        /// Token of the interaction.
+        interaction_token: &'a str,
+        /// ID of the followup message.
+        message_id: u64,
+    },
     /// Route information to get basic gateway information.
     GetGateway,
     /// Route information to get gateway information tailored to the current
     /// user.
     GetGatewayBot,
+    /// Route information to get a global command for an application.
+    GetGlobalCommand {
+        /// ID of the owner application.
+        application_id: u64,
+        /// ID of the command.
+        command_id: u64,
+    },
     GetGlobalCommands {
         /// The ID of the owner application.
         application_id: u64,
@@ -376,6 +416,15 @@ pub enum Route<'a> {
         /// guild.
         with_counts: bool,
     },
+    /// Route information to get a guild command.
+    GetGuildCommand {
+        /// ID of the owner application.
+        application_id: u64,
+        /// ID of the command.
+        command_id: u64,
+        /// ID of the guild.
+        guild_id: u64,
+    },
     /// Route information to get permissions of all guild commands.
     GetGuildCommandPermissions {
         /// The ID of the application.
@@ -524,6 +573,33 @@ pub enum Route<'a> {
         /// The ID of the channel.
         channel_id: u64,
     },
+    /// Route information to get joined private archived threads in a channel.
+    GetJoinedPrivateArchivedThreads {
+        /// Optional timestamp to return threads before.
+        before: Option<u64>,
+        /// ID of the channel.
+        channel_id: u64,
+        /// Optional maximum number of threads to return.
+        limit: Option<u64>,
+    },
+    /// Route information to get private archived threads in a channel.
+    GetPrivateArchivedThreads {
+        /// Optional timestamp to return threads before.
+        before: Option<&'a str>,
+        /// ID of the channel.
+        channel_id: u64,
+        /// Optional maximum number of threads to return.
+        limit: Option<u64>,
+    },
+    /// Route information to get public archived threads in a channel.
+    GetPublicArchivedThreads {
+        /// Optional timestamp to return threads before.
+        before: Option<&'a str>,
+        /// ID of the channel.
+        channel_id: u64,
+        /// Optional maximum number of threads to return.
+        limit: Option<u64>,
+    },
     /// Route information to get the users who reacted to a message with a
     /// specified emoji.
     GetReactionUsers {
@@ -553,6 +629,11 @@ pub enum Route<'a> {
         /// The ID of the guild.
         guild_id: u64,
     },
+    /// Route information to get members of a thread.
+    GetThreadMembers {
+        /// ID of the thread.
+        channel_id: u64,
+    },
     /// Route information to get a user.
     GetUser {
         /// ID of the target user.
@@ -588,11 +669,21 @@ pub enum Route<'a> {
         /// The token for the interaction.
         interaction_token: &'a str,
     },
+    /// Route information to join a thread as the current user.
+    JoinThread {
+        /// ID of the thread.
+        channel_id: u64,
+    },
     /// Route information to leave the guild.
     LeaveGuild {
         /// The ID of the guild.
         guild_id: u64,
     },
+    /// Route information to leave a thread as the current user.
+    LeaveThread {
+        /// ID of the thread.
+        channel_id: u64,
+    },
     /// Route information to pin a message to a channel.
     PinMessage {
         /// The ID of the channel.
@@ -616,6 +707,13 @@ pub enum Route<'a> {
         /// The ID of the user.
         user_id: u64,
     },
+    /// Route information to remove a member from a thread.
+    RemoveThreadMember {
+        /// ID of the thread.
+        channel_id: u64,
+        /// ID of the member.
+        user_id: u64,
+    },
     /// Route information to search for members in a guild.
     SearchGuildMembers {
         /// ID of the guild to search in.
@@ -897,10 +995,13 @@ impl<'a> Route<'a> {
             | Self::DeleteWebhookMessage { .. }
             | Self::DeleteWebhook { .. }
             | Self::LeaveGuild { .. }
+            | Self::LeaveThread { .. }
             | Self::RemoveMember { .. }
             | Self::RemoveMemberRole { .. }
+            | Self::RemoveThreadMember { .. }
             | Self::UnpinMessage { .. } => Method::Delete,
-            Self::GetAuditLogs { .. }
+            Self::GetActiveThreads { .. }
+            | Self::GetAuditLogs { .. }
             | Self::GetBan { .. }
             | Self::GetBans { .. }
             | Self::GetGatewayBot
@@ -914,8 +1015,11 @@ impl<'a> Route<'a> {
             | Self::GetEmoji { .. }
             | Self::GetEmojis { .. }
             | Self::GetGateway
+            | Self::GetFollowupMessage { .. }
+            | Self::GetGlobalCommand { .. }
             | Self::GetGlobalCommands { .. }
             | Self::GetGuild { .. }
+            | Self::GetGuildCommand { .. }
             | Self::GetGuildCommandPermissions { .. }
             | Self::GetGuildCommands { .. }
             | Self::GetGuildIntegrations { .. }
@@ -937,10 +1041,14 @@ impl<'a> Route<'a> {
             | Self::GetMessage { .. }
             | Self::GetMessages { .. }
             | Self::GetPins { .. }
+            | Self::GetJoinedPrivateArchivedThreads { .. }
+            | Self::GetPrivateArchivedThreads { .. }
+            | Self::GetPublicArchivedThreads { .. }
             | Self::GetReactionUsers { .. }
             | Self::GetStageInstance { .. }
             | Self::GetTemplate { .. }
             | Self::GetTemplates { .. }
+            | Self::GetThreadMembers { .. }
             | Self::GetUserConnections
             | Self::GetUserPrivateChannels
             | Self::GetUser { .. }
@@ -981,6 +1089,8 @@ impl<'a> Route<'a> {
             | Self::CreateInvite { .. }
             | Self::CreateMessage { .. }
             | Self::CreatePrivateChannel
+            | Self::CreateThread { .. }
+            | Self::CreateThreadFromMessage { .. }
             | Self::CreateRole { .. }
             | Self::CreateStageInstance { .. }
             | Self::CreateTemplate { .. }
@@ -994,8 +1104,10 @@ impl<'a> Route<'a> {
             | Self::SyncGuildIntegration { .. } => Method::Post,
             Self::AddGuildMember { .. }
             | Self::AddMemberRole { .. }
+            | Self::AddThreadMember { .. }
             | Self::CreateBan { .. }
             | Self::CreateReaction { .. }
+            | Self::JoinThread { .. }
             | Self::PinMessage { .. }
             | Self::SetCommandPermissions { .. }
             | Self::SetGlobalCommands { .. }
@@ -1045,6 +1157,13 @@ impl<'a> Route<'a> {
             Self::AddMemberRole { guild_id, .. } | Self::RemoveMemberRole { guild_id, .. } => {
                 Path::GuildsIdMembersIdRolesId(*guild_id)
             }
+            Self::AddThreadMember { channel_id, .. }
+            | Self::GetThreadMembers { channel_id, .. }
+            | Self::JoinThread { channel_id, .. }
+            | Self::LeaveThread { channel_id, .. }
+            | Self::RemoveThreadMember { channel_id, .. } => {
+                Path::ChannelsIdThreadMembers(*channel_id)
+            }
             Self::CreateBan { guild_id, .. } | Self::DeleteBan { guild_id, .. } => {
                 Path::GuildsIdBansUserId(*guild_id)
             }
@@ -1062,6 +1181,7 @@ impl<'a> Route<'a> {
             }
             Self::CreateGuildCommand { application_id, .. }
             | Self::DeleteGuildCommand { application_id, .. }
+            | Self::GetGuildCommand { application_id, .. }
             | Self::GetGuildCommandPermissions { application_id, .. }
             | Self::GetGuildCommands { application_id, .. }
             | Self::SetCommandPermissions { application_id, .. }
@@ -1095,6 +1215,10 @@ impl<'a> Route<'a> {
             Self::CreateTemplate { guild_id } | Self::GetTemplates { guild_id } => {
                 Path::GuildsIdTemplates(*guild_id)
             }
+            Self::CreateThread { channel_id, .. } => Path::ChannelsIdThreads(*channel_id),
+            Self::CreateThreadFromMessage { channel_id, .. } => {
+                Path::ChannelsIdMessagesIdThreads(*channel_id)
+            }
             Self::CreateTypingTrigger { channel_id } => Path::ChannelsIdTyping(*channel_id),
             Self::CreateWebhook { channel_id } | Self::GetChannelWebhooks { channel_id } => {
                 Path::ChannelsIdWebhooks(*channel_id)
@@ -1105,6 +1229,7 @@ impl<'a> Route<'a> {
             Self::DeleteChannel { channel_id } => Path::ChannelsId(*channel_id),
             Self::DeleteEmoji { guild_id, .. } => Path::GuildsIdEmojisId(*guild_id),
             Self::DeleteGlobalCommand { application_id, .. }
+            | Self::GetGlobalCommand { application_id, .. }
             | Self::UpdateGlobalCommand { application_id, .. } => {
                 Path::ApplicationCommandId(*application_id)
             }
@@ -1114,6 +1239,7 @@ impl<'a> Route<'a> {
                 Path::GuildsIdIntegrationsId(*guild_id)
             }
             Self::DeleteInteractionOriginal { application_id, .. }
+            | Self::GetFollowupMessage { application_id, .. }
             | Self::GetInteractionOriginal { application_id, .. }
             | Self::UpdateInteractionOriginal { application_id, .. } => {
                 Path::WebhooksIdTokenMessagesId(*application_id)
@@ -1150,6 +1276,12 @@ impl<'a> Route<'a> {
             | Self::GetWebhook { webhook_id, .. }
             | Self::UpdateWebhook { webhook_id, .. } => (Path::WebhooksId(*webhook_id)),
             Self::FollowNewsChannel { channel_id } => Path::ChannelsIdFollowers(*channel_id),
+            Self::GetJoinedPrivateArchivedThreads { channel_id, .. }
+            | Self::GetPrivateArchivedThreads { channel_id, .. }
+            | Self::GetPublicArchivedThreads { channel_id, .. } => {
+                Path::ChannelsIdThreads(*channel_id)
+            }
+            Self::GetActiveThreads { guild_id, .. } => Path::GuildsIdThreads(*guild_id),
             Self::GetAuditLogs { guild_id, .. } => Path::GuildsIdAuditLogs(*guild_id),
             Self::GetBan { guild_id, .. } => Path::GuildsIdBansId(*guild_id),
             Self::GetBans { guild_id } => Path::GuildsIdBans(*guild_id),
